@@ -1,12 +1,9 @@
 """BMT basics."""
-from typing import Dict, List, Optional
+from typing import List, Optional
 
 from .data import (
-    all_classes, all_elements, all_slots, all_types,
-    alias_ancestors, basic_ancestors, mixin_ancestors, alias_mixin_ancestors,
-    alias_descendants, basic_descendants, mixin_descendants, alias_mixin_descendants,
-    alias_children, basic_children, mixin_children, alias_mixin_children,
-    parent, element,
+    all_classes, all_elements, all_slots,
+    all_types, ancestors, descendants, children, parent, element,
 )
 from .util import with_formatting
 
@@ -40,59 +37,36 @@ class Toolkit():
         self,
         name: str,
         reflexive: bool = True,
-        mixin: bool = True,
-        alias: bool = False,
     ) -> List[str]:
         """Get ancestors."""
-        _ancestors = basic_ancestors.get(name, [])
-        if mixin:
-            _ancestors += mixin_ancestors.get(name, [])
-        if alias:
-            _ancestors += alias_ancestors.get(name, [])
-        if mixin and alias:
-            _ancestors += alias_mixin_ancestors.get(name, [])
+        if name not in ancestors:
+            return []
         if reflexive:
-            return _ancestors + [name]
+            return ancestors[name] + [name]
         else:
-            return _ancestors
+            return ancestors[name]
 
     @with_formatting()
     def get_descendants(
         self,
         name: str,
         reflexive: bool = True,
-        mixin: bool = True,
-        alias: bool = False,
     ) -> List[str]:
         """Get descendants."""
-        _descendants = basic_descendants.get(name, [])
-        if mixin:
-            _descendants += mixin_descendants.get(name, [])
-        if alias:
-            _descendants += alias_descendants.get(name, [])
-        if mixin and alias:
-            _descendants += alias_mixin_descendants.get(name, [])
+        if name not in descendants:
+            return []
         if reflexive:
-            return _descendants + [name]
+            return descendants[name] + [name]
         else:
-            return _descendants
+            return descendants[name]
 
     @with_formatting()
     def get_children(
         self,
         name: str,
-        mixin: bool = True,
-        alias: bool = False,
     ) -> List[str]:
         """Get children."""
-        _children = basic_children.get(name, [])
-        if mixin:
-            _children += mixin_children.get(name, [])
-        if alias:
-            _children += alias_children.get(name, [])
-        if mixin and alias:
-            _children += alias_mixin_children.get(name, [])
-        return _children
+        return children.get(name, [])
 
     @with_formatting()
     def get_parent(
@@ -115,19 +89,11 @@ class Toolkit():
         return None
 
 
-class AttrDict(dict):
-    """https://stackoverflow.com/a/14620633"""
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.__dict__ = self
-
-
-class Element(AttrDict):
+class Element():
     """Biolink model element."""
 
     def __init__(self, name: str):
         """Initialize."""
-        super().__init__()
         self.name: str = name
 
 
@@ -139,18 +105,11 @@ class SlotDefinition(Element):
         name: str,
         symmetric: bool = False,
         inverse: Optional[str] = None,
-        annotations: Dict[str, bool] = dict(),
-        slot_uri: Optional[str] = None,
-        range: Optional[str] = None,
-        **kwargs,
     ):
         """Initialize."""
         super().__init__(name)
         self.symmetric: bool = symmetric
         self.inverse: Optional[str] = inverse
-        self.annotations: Dict[str, bool] = annotations
-        self.slot_uri: Optional[str] = slot_uri
-        self.range: Optional[str] = range
 
 
 class ClassDefinition(Element):
@@ -160,9 +119,7 @@ class ClassDefinition(Element):
         self,
         name: str,
         id_prefixes: List[str],
-        mixins: List[str],
     ):
         """Initialize."""
         super().__init__(name)
         self.id_prefixes: List[str] = id_prefixes
-        self.mixins: List[str] = mixins
